@@ -54,6 +54,7 @@
 #' @param lower see \code{\link[stats]{optim}}
 #' @param upper see \code{\link[stats]{optim}}
 #' @param control see \code{\link[stats]{optim}}
+#' @param periodicity Option for a periodic spline basis. Defaults to FALSE.
 #' @return A list with components
 #' \enumerate{
 #' \item \code{Yhat} - If \code{Y.pred} is specified, the smooth version of
@@ -143,7 +144,8 @@ function(Y=NULL,ydata=NULL,Y.pred = NULL,argvals=NULL,pve = 0.99, npc  = NULL,
          var = FALSE, simul = FALSE, sim.alpha = 0.95,
          center=TRUE,knots=35,p=3,m=2,lambda=NULL,alpha = 1,
          search.grid=TRUE,search.length=100,
-         method="L-BFGS-B", lower=-20,upper=20, control=NULL){
+         method="L-BFGS-B", lower=-20,upper=20, control=NULL,
+         periodicity = FALSE){
 
   ## data: Y, I by J data matrix, functions on rows
   ## argvals:  vector of J
@@ -188,7 +190,7 @@ function(Y=NULL,ydata=NULL,Y.pred = NULL,argvals=NULL,pve = 0.99, npc  = NULL,
   c.p <- K.p + p.p
 
   ######### precalculation for smoothing #############
-  List <- pspline.setting(argvals,knots,p.p,m.p)
+  List <- pspline.setting(argvals,knots,p.p,m.p, periodicity=periodicity)
   B <- List$B
   Bt <- Matrix(t(as.matrix(B)))
   s <- List$s
